@@ -251,7 +251,7 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
     if http_url:
         maxrows = 100000 ### set it very high so that all rows are read into dataframe ###
     else:
-        maxrows = max(100000, int(0.25*DS_LEN))
+        maxrows = min(100000, int(0.25*DS_LEN))
         print('Max rows loaded to classify features = %s' %maxrows)
     ### first load a small sample of the dataframe and the entire target if it needs transform
     if DS_LEN > 2*maxrows:
@@ -263,7 +263,7 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
             targets = [target]
         else:
             targets = copy.deepcopy(target)
-        nrows_limit = min(DS_LEN, 5e6) ### don't load the entire dataframe!
+        nrows_limit = min(DS_LEN, 1e5) ### don't load the entire dataframe!
         print('    Since number of rows > maxrows, loading a random sample of %d rows into pandas for EDA' %nrows_limit)
         ### load a small sample of data into a pandas dataframe ##
         train_small = pd.read_csv(train_datafile, nrows=nrows_limit, sep=sep, header=header,
@@ -1026,11 +1026,22 @@ def load_train_data(train_data_or_file, target, project_name, keras_options, mod
         for feature_name in features:
             if feature_name in BOOLS:
                 # Cast boolean feature values to string.
-                features[feature_name] = tf.cast(features[feature_name], tf.dtypes.float32)
-        return features, target
+                #features[feature_name] = tf.cast(features[feature_name], tf.dtypes.float32)
+                features[feature_name] = tf.dtypes.cast(features[feature_name], tf.int32)
+        return (features, target)
     #################################################################################
     train_ds = train_ds.map(process_boolean)
-    print('Boolean column successfully processed')
+    #################################################################################
+    ################## process boolean target if needed #############################
+    #################################################################################
+    #@tf.autograph.experimental.do_not_convert
+    @tf.function
+    def process_target(features, target):
+        target = tf.cast(target, tf.dtypes.float32)
+        return (features, target)
+    if bool in train_small[cat_vocab_dict['target_variables']].dtypes.values:
+        train_ds = train_ds.map(process_target)        
+    print('Boolean columns successfully processed')
     #################################################################################
     if keras_model_type.lower() in ['nlp', 'text']:
         NLP_VARS = cat_vocab_dict['predictors_in_train']
