@@ -96,7 +96,7 @@ from .preprocessing.preprocessing_text import preprocessing_text
 
 # keras models and bring-your-own models
 from .modeling.create_model import create_model
-from .models import basic, deep, big_deep, giant_deep, cnn1, cnn2
+from .models import basic, dnn, reg_dnn, dnn_drop, giant_deep, cnn1, cnn2
 from .modeling.train_model import train_model
 from .modeling.train_custom_model import train_custom_model
 from .modeling.predict_model import predict, predict_images, predict_text
@@ -218,6 +218,7 @@ def fit(train_data_or_file, target, keras_model_type="basic", project_name="deep
                 with minimal outputs.
     """
     my_strategy = check_if_GPU_exists(1)
+    ########    C H E CK   T Y P E    O F    K E R A S    M O D E L        #####################
     print() #### create a new line that's all ###
     model_options_copy = copy.deepcopy(model_options)
     keras_options_copy = copy.deepcopy(keras_options)
@@ -244,26 +245,25 @@ def fit(train_data_or_file, target, keras_model_type="basic", project_name="deep
 
     if keras_model_type.lower() in ['image', 'images', "image_classification"]:
         ###############   Now do special image processing here ###################################
-        with my_strategy.scope():
-            if 'image_directory' in model_options.keys():
-                print('    Image directory given as %s' %model_options['image_directory'])
-                image_dir = model_options["image_directory"]
-            else:
-                print("    No image directory given. Provide image directory in model_options...")
-                return
-            try:
-                print('For image use case:')
-                train_ds, valid_ds, cat_vocab_dict, model_options = load_image_data(image_dir,
-                                                        project_name, keras_options_copy,
-                                                        model_options_copy, verbose)
-            except:
-                print('    Error in image loading: check your model_options and try again.')
-                return
-            try:
-                deep_model = preprocessing_images(train_ds, model_options)
-            except:
-                print('    Error in image preprocessing: check your model_options and try again.')
-                return
+        if 'image_directory' in model_options.keys():
+            print('    Image directory given as %s' %model_options['image_directory'])
+            image_dir = model_options["image_directory"]
+        else:
+            print("    No image directory given. Provide image directory in model_options...")
+            return
+        try:
+            print('For image use case:')
+            train_ds, valid_ds, cat_vocab_dict, model_options = load_image_data(image_dir,
+                                                    project_name, keras_options_copy,
+                                                    model_options_copy, verbose)
+        except:
+            print('    Error in image loading: check your model_options and try again.')
+            return
+        try:
+            deep_model = preprocessing_images(train_ds, model_options)
+        except:
+            print('    Error in image preprocessing: check your model_options and try again.')
+            return
         ##########    E N D    O F    S T R A T E G Y    S C O P E   #############
         deep_model, cat_vocab_dict = train_image_model(deep_model, train_ds, valid_ds,
                                         cat_vocab_dict, keras_options_copy, model_options_copy,
@@ -272,185 +272,180 @@ def fit(train_data_or_file, target, keras_model_type="basic", project_name="deep
         return deep_model, cat_vocab_dict
     elif keras_model_type.lower() in ['text', 'text classification', "text_classification"]:
         ###############   Now do special image processing here ###################################
-        with my_strategy.scope():
-            text_alt = True ### This means you use the text directory option
-            if 'text_directory' in model_options.keys():
-                print('    text directory given as %s' %model_options['text_directory'])
-                text_dir = model_options["text_directory"]
-            else:
-                print("    No text directory given. Using train data given as input..." )
-                text_alt = False ## this means you use the text file given
-            ################   T E X T    C L A S S I F I C A T I O N   #########
-            if text_alt:
-                try:
-                    train_ds, valid_ds, cat_vocab_dict, model_options = load_text_data(text_dir,
-                                                            project_name, keras_options_copy,
-                                                            model_options_copy, verbose)
-                except:
-                    print('    Error in text folder loading: check your folder name and try again.')
-                    return
-            else:
-                #### Use the text file given and split it into train and valid_ds ####
-                dft, model_options, full_ds, var_df, cat_vocab_dict, keras_options = load_train_data(
-                                    train_data_or_file, target, project_name, keras_options_copy,
-                                    model_options_copy, keras_model_type, verbose=verbose)
-                print('Loaded text classification file or dataframe using input given:')
-                ############## Split train into train and validation datasets here ###############
-                recover = lambda x,y: y
-                print('\nSplitting train into 80+20 percent: train and validation data')
-                valid_ds = full_ds.enumerate().filter(is_valid).map(recover)
-                train_ds = full_ds.enumerate().filter(is_train).map(recover)
-            ###################  P R E P R O C E S S    T E X T   #########################
+        text_alt = True ### This means you use the text directory option
+        if 'text_directory' in model_options.keys():
+            print('    text directory given as %s' %model_options['text_directory'])
+            text_dir = model_options["text_directory"]
+        else:
+            print("    No text directory given. Using train data given as input..." )
+            text_alt = False ## this means you use the text file given
+        ################   T E X T    C L A S S I F I C A T I O N   #########
+        if text_alt:
             try:
-                deep_model = preprocessing_text(train_ds, keras_model_type, model_options)
+                train_ds, valid_ds, cat_vocab_dict, model_options = load_text_data(text_dir,
+                                                        project_name, keras_options_copy,
+                                                        model_options_copy, verbose)
             except:
-                print('    Error in text preprocessing: check your model_options and try again.')
+                print('    Error in text folder loading: check your folder name and try again.')
                 return
-        ##########    E N D    O F    S T R A T E G Y    S C O P E   #############
+        else:
+            #### Use the text file given and split it into train and valid_ds ####
+            dft, model_options, full_ds, var_df, cat_vocab_dict, keras_options = load_train_data(
+                                train_data_or_file, target, project_name, keras_options_copy,
+                                model_options_copy, keras_model_type, verbose=verbose)
+            print('Loaded text classification file or dataframe using input given:')
+            ############## Split train into train and validation datasets here ###############
+            recover = lambda x,y: y
+            print('\nSplitting train into 80+20 percent: train and validation data')
+            valid_ds = full_ds.enumerate().filter(is_valid).map(recover)
+            train_ds = full_ds.enumerate().filter(is_train).map(recover)
+        ###################  P R E P R O C E S S    T E X T   #########################
+        try:
+            deep_model = preprocessing_text(train_ds, keras_model_type, model_options)
+        except:
+            print('    Error in text preprocessing: check your model_options and try again.')
+            return
+
         deep_model, cat_vocab_dict = train_text_model(deep_model, train_ds, valid_ds,
                                             cat_vocab_dict, keras_options_copy,
                                             project_name, save_model_flag)
         print(deep_model.summary())
         return deep_model, cat_vocab_dict
 
-    ########    B E G I N N I N G    O F    S T R A T E G Y    S C O P E    #####################
-    with my_strategy.scope():
+    shuffle_flag = False
+    ####   K E R A S    O P T I O N S   - THESE CAN BE OVERRIDDEN by your input keras_options dictionary ####
+    keras_options_defaults = {}
+    keras_options_defaults["batchsize"] = ""
+    keras_options_defaults['activation'] = ''
+    keras_options_defaults['save_weights_only'] = True
+    keras_options_defaults['use_bias'] = True
+    keras_options_defaults["patience"] = "" ### patience of 20 seems ideal.
+    keras_options_defaults["epochs"] = "" ## 500 seems ideal for most scenarios ####
+    keras_options_defaults["steps_per_epoch"] = "" ### 10 seems ideal for most scenarios
+    keras_options_defaults['optimizer'] = "RMSprop"
+    keras_options_defaults['kernel_initializer'] =  ''
+    keras_options_defaults['num_layers'] = ""
+    keras_options_defaults['loss'] = ""
+    keras_options_defaults['metrics'] = ""
+    keras_options_defaults['monitor'] = ""
+    keras_options_defaults['mode'] = ""
+    keras_options_defaults["lr_scheduler"] = ""
+    keras_options_defaults["early_stopping"] = True
+    keras_options_defaults["class_weight"] = {}
 
-        shuffle_flag = False
-        ####   K E R A S    O P T I O N S   - THESE CAN BE OVERRIDDEN by your input keras_options dictionary ####
-        keras_options_defaults = {}
-        keras_options_defaults["batchsize"] = ""
-        keras_options_defaults['activation'] = ''
-        keras_options_defaults['save_weights_only'] = True
-        keras_options_defaults['use_bias'] = True
-        keras_options_defaults["patience"] = "" ### patience of 20 seems ideal.
-        keras_options_defaults["epochs"] = "" ## 500 seems ideal for most scenarios ####
-        keras_options_defaults["steps_per_epoch"] = "" ### 10 seems ideal for most scenarios
-        keras_options_defaults['optimizer'] = "RMSprop"
-        keras_options_defaults['kernel_initializer'] =  ''
-        keras_options_defaults['num_layers'] = ""
-        keras_options_defaults['loss'] = ""
-        keras_options_defaults['metrics'] = ""
-        keras_options_defaults['monitor'] = ""
-        keras_options_defaults['mode'] = ""
-        keras_options_defaults["lr_scheduler"] = ""
-        keras_options_defaults["early_stopping"] = True
-        keras_options_defaults["class_weight"] = {}
+    list_of_keras_options = ["batchsize", "activation", "save_weights_only", "use_bias",
+                            "patience", "epochs", "steps_per_epoch", "optimizer",
+                            "kernel_initializer", "num_layers", "class_weight",
+                            "loss", "metrics", "monitor","mode", "lr_scheduler","early_stopping",
+                            "class_weight"]
 
-        list_of_keras_options = ["batchsize", "activation", "save_weights_only", "use_bias",
-                                "patience", "epochs", "steps_per_epoch", "optimizer",
-                                "kernel_initializer", "num_layers", "class_weight",
-                                "loss", "metrics", "monitor","mode", "lr_scheduler","early_stopping",
-                                "class_weight"]
+    keras_options = copy.deepcopy(keras_options_defaults)
+    if len(keras_options_copy) > 0:
+        print('Using following keras_options given as input:')
+        for key in list_of_keras_options:
+            if key in keras_options_copy.keys():
+                print('    %s : %s' %(key, keras_options_copy[key]))
+                keras_options[key] = keras_options_copy[key]
 
-        keras_options = copy.deepcopy(keras_options_defaults)
-        if len(keras_options_copy) > 0:
-            print('Using following keras_options given as input:')
-            for key in list_of_keras_options:
-                if key in keras_options_copy.keys():
-                    print('    %s : %s' %(key, keras_options_copy[key]))
-                    keras_options[key] = keras_options_copy[key]
+    list_of_model_options = ["idcols","modeltype","sep","cat_feat_cross_flag", "model_use_case",
+                            "nlp_char_limit", "variable_cat_limit", "csv_encoding", "header",
+                            "max_trials","tuner", "embedding_size", "tf_hub_model", "image_directory",
+                            'image_height', 'image_width', "image_channels", "save_model_path"]
 
-        list_of_model_options = ["idcols","modeltype","sep","cat_feat_cross_flag", "model_use_case",
-                                "nlp_char_limit", "variable_cat_limit", "csv_encoding", "header",
-                                "max_trials","tuner", "embedding_size", "tf_hub_model", "image_directory",
-                                'image_height', 'image_width', "image_channels", "save_model_path"]
+    model_options_defaults = defaultdict(str)
+    model_options_defaults["idcols"] = []
+    model_options_defaults["modeltype"] = ''
+    model_options_defaults["save_model_format"] = ""
+    model_options_defaults["sep"] = ","
+    model_options_defaults["cat_feat_cross_flag"] = False
+    model_options_defaults["model_use_case"] = ''
+    model_options_defaults["nlp_char_limit"] = 30
+    model_options_defaults["variable_cat_limit"] = 30
+    model_options_defaults["csv_encoding"] = 'utf-8'
+    model_options_defaults["header"] = 0 ### this is the header row for pandas to read
+    model_options_defaults["max_trials"] = 30 ## number of Storm Tuner trials ###
+    model_options_defaults['tuner'] = 'storm'  ## Storm Tuner is the default tuner. Optuna is the other option.
+    model_options_defaults["embedding_size"] = "" ## this is the NLP embedding size minimum
+    model_options_defaults["tf_hub_model"] = "" ## If you want to use a pretrained Hub model, provide URL here.
+    model_options_defaults["image_directory"] = "" ## this is where images are input in form of folder
+    model_options_defaults['image_height'] = "" ## the height of the image must be given in number of pixels
+    model_options_defaults['image_width'] = "" ## the width of the image must be given in number of pixels
+    model_options_defaults["image_channels"] = "" ## number of channels in images provided
+    model_options_defaults['save_model_path'] = save_model_path
 
-        model_options_defaults = defaultdict(str)
-        model_options_defaults["idcols"] = []
-        model_options_defaults["modeltype"] = ''
-        model_options_defaults["save_model_format"] = ""
-        model_options_defaults["sep"] = ","
-        model_options_defaults["cat_feat_cross_flag"] = False
-        model_options_defaults["model_use_case"] = ''
-        model_options_defaults["nlp_char_limit"] = 30
-        model_options_defaults["variable_cat_limit"] = 30
-        model_options_defaults["csv_encoding"] = 'utf-8'
-        model_options_defaults["header"] = 0 ### this is the header row for pandas to read
-        model_options_defaults["max_trials"] = 30 ## number of Storm Tuner trials ###
-        model_options_defaults['tuner'] = 'storm'  ## Storm Tuner is the default tuner. Optuna is the other option.
-        model_options_defaults["embedding_size"] = "" ## this is the NLP embedding size minimum
-        model_options_defaults["tf_hub_model"] = "" ## If you want to use a pretrained Hub model, provide URL here.
-        model_options_defaults["image_directory"] = "" ## this is where images are input in form of folder
-        model_options_defaults['image_height'] = "" ## the height of the image must be given in number of pixels
-        model_options_defaults['image_width'] = "" ## the width of the image must be given in number of pixels
-        model_options_defaults["image_channels"] = "" ## number of channels in images provided
-        model_options_defaults['save_model_path'] = save_model_path
+    model_options = copy.deepcopy(model_options_defaults)
+    if len(model_options_copy) > 0:
+        print('Using following model_options given as input:')
+        for key in list_of_model_options:
+            if key in model_options_copy.keys():
+                print('    %s : %s' %(key, model_options_copy[key]))
+                model_options[key] = model_options_copy[key]
 
-        model_options = copy.deepcopy(model_options_defaults)
-        if len(model_options_copy) > 0:
-            print('Using following model_options given as input:')
-            for key in list_of_model_options:
-                if key in model_options_copy.keys():
-                    print('    %s : %s' %(key, model_options_copy[key]))
-                    model_options[key] = model_options_copy[key]
-
-        fast_models = ['deep_and_wide','deep_wide','wide_deep', 'wide_and_deep','deep wide',
-                'wide deep', 'fast','fast1', 'fast2', 'deep_and_cross', 'deep cross', 'deep and cross']
-        if keras_model_type.lower() in fast_models:
-            print('max_trials set to 10 for fast models. Please increase it if you want better performance...')
-            model_options["max_trials"] = 10
+    fast_models = ['deep_and_wide','deep_wide','wide_deep', 'wide_and_deep','deep wide',
+            'wide deep', 'fast','fast1', 'fast2', 'deep_and_cross', 'deep cross', 'deep and cross']
+    if keras_model_type.lower() in fast_models:
+        print('max_trials set to 10 for fast models. Please increase it if you want better performance...')
+        model_options["max_trials"] = 10
+    else:
+        if model_options["max_trials"] <= 20:
+            print('Max Trials : %s. Please increase max_trials if you want to better accuracy...' %model_options["max_trials"])
         else:
-            if model_options["max_trials"] <= 20:
-                print('Max Trials : %s. Please increase max_trials if you want to better accuracy...' %model_options["max_trials"])
-            else:
-                print('Max Trials : %s. Please lower max_trials if you want to run faster...' %model_options["max_trials"])
+            print('Max Trials : %s. Please lower max_trials if you want to run faster...' %model_options["max_trials"])
 
-        print("""
-    #################################################################################
-    ###########     L O A D I N G    D A T A    I N T O   TF.DATA.DATASET H E R E  #
-    #################################################################################
-            """)
-        dft, model_options, batched_data, var_df, cat_vocab_dict, keras_options = load_train_data(
-                                        train_data_or_file, target, project_name, keras_options,
-                                        model_options, keras_model_type, verbose=verbose)
+    print("""
+#################################################################################
+###########     L O A D I N G    D A T A    I N T O   TF.DATA.DATASET H E R E  #
+#################################################################################
+        """)
+    dft, model_options, batched_data, var_df, cat_vocab_dict, keras_options = load_train_data(
+                                    train_data_or_file, target, project_name, keras_options,
+                                    model_options, keras_model_type, verbose=verbose)
 
-        try:
-            data_size = cat_vocab_dict['DS_LEN']
-        except:
-            data_size = 10000
-            cat_vocab_dict['DS_LEN'] = data_size
+    try:
+        data_size = cat_vocab_dict['DS_LEN']
+    except:
+        data_size = 10000
+        cat_vocab_dict['DS_LEN'] = data_size
 
-        modeltype = model_options['modeltype']
+    modeltype = model_options['modeltype']
 
-        ##########  Perform keras preprocessing here by building all layers needed #############
-        print("""
-    #################################################################################
-    ###########     K E R A S     F E A T U R E    P R E P R O C E S S I N G  #######
-    #################################################################################
-            """)
+    ##########  Perform keras preprocessing here by building all layers needed #############
+    print("""
+#################################################################################
+###########     K E R A S     F E A T U R E    P R E P R O C E S S I N G  #######
+#################################################################################
+        """)
 
-        nlp_inputs, meta_inputs, meta_outputs, nlp_outputs = perform_preprocessing(batched_data, var_df,
-                                                    cat_vocab_dict, keras_model_type,
-                                                    keras_options, model_options,
-                                                    verbose)
+    nlp_inputs, meta_inputs, meta_outputs, nlp_outputs = perform_preprocessing(batched_data, var_df,
+                                                cat_vocab_dict, keras_model_type,
+                                                keras_options, model_options,
+                                                verbose)
 
-        if isinstance(model_use_case, str):
-            if model_use_case:
-                if model_use_case.lower() == 'pipeline':
-                    ##########  Perform keras preprocessing only and return inputs + keras layers created ##
-                    print('\nReturning a keras pipeline so you can create your own Functional model.')
-                    return nlp_inputs, meta_inputs, meta_outputs, nlp_outputs
-                #### There may be other use cases for model_use_case in future hence leave this empty for now #
+    if isinstance(model_use_case, str):
+        if model_use_case:
+            if model_use_case.lower() == 'pipeline':
+                ##########  Perform keras preprocessing only and return inputs + keras layers created ##
+                print('\nReturning a keras pipeline so you can create your own Functional model.')
+                return nlp_inputs, meta_inputs, meta_outputs, nlp_outputs
+            #### There may be other use cases for model_use_case in future hence leave this empty for now #
 
-        #### you must create a functional model here
-        print('\nCreating a new Functional model here...')
-        print('''
-    #################################################################################
-    ###########     C R E A T I N G    A    K E R A S       M O D E L    ############
-    #################################################################################
-            ''')
-        ######### this is where you get the model body either by yourself or sent as input ##
-        ##### This takes care of providing multi-output predictions! ######
-        model_body, keras_options =  create_model(use_my_model, nlp_inputs, meta_inputs, meta_outputs,
-                                            nlp_outputs, keras_options, var_df, keras_model_type,
-                                            model_options, cat_vocab_dict)
+    #### you must create a functional model here
+    print('\nCreating a new Functional model here...')
+    print('''
+#################################################################################
+###########     C R E A T I N G    A    K E R A S       M O D E L    ############
+#################################################################################
+        ''')
+    ######### this is where you get the model body either by yourself or sent as input ##
+    ##### This takes care of providing multi-output predictions! ######
+    model_body, keras_options =  create_model(use_my_model, nlp_inputs, meta_inputs, meta_outputs,
+                                        nlp_outputs, keras_options, var_df, keras_model_type,
+                                        model_options, cat_vocab_dict)
 
-        ###########    C O M P I L E    M O D E L    H E R E         #############
-        ### For auto models we will add input and output layers later. See below... #########
-        deep_model = model_body
+    ###########    C O M P I L E    M O D E L    H E R E         #############
+    ### For auto models we will add input and output layers later. See below... #########
+    deep_model = model_body
 
-    ##########    E N D    O F    S T R A T E G Y    S C O P E   #############
 
     if dft.shape[1] <= 100 :
         plot_filename = save_model_architecture(deep_model, project_name, keras_model_type, cat_vocab_dict,
@@ -465,29 +460,21 @@ def fit(train_data_or_file, target, keras_model_type="basic", project_name="deep
 ###########     T R A I N I N G    K E R A S   M O D E L   H E R E      #########
 #################################################################################
     """)
-    if keras_model_type.lower() in ['auto','mixed_nlp']:
+
+    if keras_model_type.lower() not in ['auto','mixed_nlp']:
+        print('Training a %s model option...' %keras_model_type)
+        deep_model, cat_vocab_dict = train_model(deep_model, batched_data, target, keras_model_type,
+                        keras_options, model_options, var_df, cat_vocab_dict, project_name, save_model_flag, verbose)
+    else:
+        #### This is used only for custom auto models and is out of the strategy scope #######
         print('Building and training an automatic model using %s Tuner...' %model_options['tuner'])
         deep_model, cat_vocab_dict = train_custom_model(nlp_inputs, meta_inputs, meta_outputs, nlp_outputs,
                                          batched_data, target, keras_model_type, keras_options,
                                          model_options, var_df, cat_vocab_dict, project_name,
                                             save_model_flag, use_my_model, verbose)
-    else:
-        print('Training a %s model option...' %keras_model_type)
-        deep_model, cat_vocab_dict = train_model(deep_model, batched_data, target, keras_model_type,
-                        keras_options, model_options, var_df, cat_vocab_dict, project_name, save_model_flag, verbose)
-
-    ##### Plot the model again after you have done model search #############
-    if dft.shape[1] <= 100 :
-        plot_filename = save_model_architecture(deep_model, project_name, keras_model_type, cat_vocab_dict,
-                        model_options, chart_name="model_after")
-        if plot_filename != "":
-            try:
-                display(Image(retina=True, filename=plot_filename))
-            except:
-                print('Cannot save plot. Install pydot and graphviz if you want plots saved.')
-                
     distributed_values = (deep_model, cat_vocab_dict)
     return distributed_values
+
 ############################################################################################
 def save_model_architecture(model, project_name, keras_model_type, cat_vocab_dict, 
                     model_options, chart_name="model_before"):
